# Django injector

Django injector is an app for Django that integrates [injector](https://github.com/alecthomas/injector)
with Django.

Injector is a simple and easy to use dependency injection framework.
